summaryrefslogtreecommitdiffstats
path: root/testing/web-platform/tests/tools/third_party/pywebsocket3/test/test_handshake.py
diff options
context:
space:
mode:
Diffstat (limited to 'testing/web-platform/tests/tools/third_party/pywebsocket3/test/test_handshake.py')
-rwxr-xr-xtesting/web-platform/tests/tools/third_party/pywebsocket3/test/test_handshake.py17
1 files changed, 9 insertions, 8 deletions
diff --git a/testing/web-platform/tests/tools/third_party/pywebsocket3/test/test_handshake.py b/testing/web-platform/tests/tools/third_party/pywebsocket3/test/test_handshake.py
index 7f4acf56ff..c8e25ab099 100755
--- a/testing/web-platform/tests/tools/third_party/pywebsocket3/test/test_handshake.py
+++ b/testing/web-platform/tests/tools/third_party/pywebsocket3/test/test_handshake.py
@@ -31,16 +31,17 @@
"""Tests for handshake.base module."""
from __future__ import absolute_import
-import unittest
-import set_sys_path # Update sys.path to locate mod_pywebsocket module.
+import unittest
-from mod_pywebsocket.common import ExtensionParameter
-from mod_pywebsocket.common import ExtensionParsingException
-from mod_pywebsocket.common import format_extensions
-from mod_pywebsocket.common import parse_extensions
-from mod_pywebsocket.handshake.base import HandshakeException
-from mod_pywebsocket.handshake.base import validate_subprotocol
+import set_sys_path # Update sys.path to locate pywebsocket3 module.
+from pywebsocket3.common import (
+ ExtensionParameter,
+ ExtensionParsingException,
+ format_extensions,
+ parse_extensions,
+)
+from pywebsocket3.handshake.base import HandshakeException, validate_subprotocol
class ValidateSubprotocolTest(unittest.TestCase):